==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/gui/win32/main.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#define ACE_DOESNT_INSTANTIATE_NONSTATIC_OBJECT_MANAGER

#include <ace/config-lite.h>
#include <ace/ACE.h>
#include <wx/wx.h>
#include <windows.h>
#include <mmsystem.h>
#include <stdio.h>

int WINAPI
WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	if (__argc == 1 && !strcmp(__argv[0], "--have-win9x-support")) {
		// used by mkinst.py to decide on the installer name
#if ACE_HAS_WINNT4
		return 0;
#else
		return 1;
#endif
	}
	
#ifdef DEBUG
	freopen("out.txt", "ab", stdout);
	freopen("out.txt", "ab", stderr);
	setvbuf(stdout, 0, _IONBF, 0);
	setvbuf(stderr, 0, _IONBF, 0);
#endif
	timeBeginPeriod(1); // set the timer resolution to 1ms
	ACE::init();
	wxEntry(hInstance, hPrevInstance, lpCmdLine, nCmdShow);
	ACE::fini();
	timeEndPeriod(1);
	return 0;
}

==> bfilter_1.1.4.orig.tar.gz: bfilter-1.1.4/main/gui/win32/main.cpp <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "pch.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#define ACE_DOESNT_INSTANTIATE_NONSTATIC_OBJECT_MANAGER

#include <ace/config-lite.h>
#include <ace/ACE.h>
#include <wx/wx.h>
#include <windows.h>
#include <mmsystem.h>
#include <stdio.h>

int WINAPI
WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{	
#ifdef DEBUG
	freopen("out.txt", "ab", stdout);
	freopen("out.txt", "ab", stderr);
	setvbuf(stdout, 0, _IONBF, 0);
	setvbuf(stderr, 0, _IONBF, 0);
#endif
	timeBeginPeriod(1); // set timer resolution to 1ms
	ACE::init();
	wxEntry(hInstance, hPrevInstance, lpCmdLine, nCmdShow);
	ACE::fini();
	timeEndPeriod(1);
	return 0;
}
